@@ -66,30 +66,21 @@ void __connman_agent_cleanup(void);
 int __connman_agent_register(const char *sender, const char *path);
 int __connman_agent_unregister(const char *sender, const char *path);
 
-struct connman_service;
-struct connman_ipconfig;
-
+void __connman_counter_send_usage(const char *path,
+					DBusMessage *message);
 int __connman_counter_register(const char *owner, const char *path,
 						unsigned int interval);
 int __connman_counter_unregister(const char *owner, const char *path);
 
-void __connman_counter_notify(struct connman_ipconfig *config,
-			unsigned int rx_packets, unsigned int tx_packets,
-			unsigned int rx_bytes, unsigned int tx_bytes,
-			unsigned int rx_error, unsigned int tx_error,
-			unsigned int rx_dropped, unsigned int tx_dropped);
-
-int __connman_counter_add_service(struct connman_service *service);
-void __connman_counter_remove_service(struct connman_service *service);
-
 int __connman_counter_init(void);
 void __connman_counter_cleanup(void);
 
+struct connman_service *service;
 
 typedef void (* passphrase_cb_t) (struct connman_service *service,
 				const char *passphrase, void *user_data);
 
-int __connman_agent_request_passphrase(struct connman_service *service,
+int __connman_agent_request_input(struct connman_service *service,
 				passphrase_cb_t callback, void *user_data);
 
 #include <connman/log.h>
@@ -112,14 +103,13 @@ void __connman_plugin_cleanup(void);
 int __connman_task_init(void);
 void __connman_task_cleanup(void);
 
-#include <connman/security.h>
-
-int __connman_security_check_privilege(DBusMessage *message,
-				enum connman_security_privilege privilege);
-
 #include <connman/inet.h>
 
-enum connman_device_type __connman_inet_get_device_type(int index);
+int __connman_inet_modify_address(int cmd, int flags, int index, int family,
+				const char *address,
+				const char *peer,
+				unsigned char prefixlen,
+				const char *broadcast);
 
 #include <connman/wifi.h>
 
@@ -188,8 +178,6 @@ void __connman_element_list(struct connman_element *element,
 
 struct connman_service *__connman_element_get_service(struct connman_element *element);
 struct connman_device *__connman_element_get_device(struct connman_element *element);
-const char *__connman_element_get_device_path(struct connman_element *element);
-const char *__connman_element_get_network_path(struct connman_element *element);
 
 struct connman_device *__connman_element_find_device(enum connman_service_type type);
 int __connman_element_request_scan(enum connman_service_type type);
@@ -198,6 +186,16 @@ int __connman_element_disable_technology(enum connman_service_type type);
 
 gboolean __connman_element_device_isfiltered(const char *devname);
 
+int __connman_detect_init(void);
+void __connman_detect_cleanup(void);
+
+void __connman_element_set_driver(struct connman_element *element);
+
+#include <connman/proxy.h>
+
+int __connman_proxy_init(void);
+void __connman_proxy_cleanup(void);
+
 #include <connman/ipconfig.h>
 
 int __connman_ipconfig_init(void);
@@ -210,13 +208,13 @@ void __connman_ipconfig_newlink(int index, unsigned short type,
 							unsigned short mtu,
 						struct rtnl_link_stats *stats);
 void __connman_ipconfig_dellink(int index, struct rtnl_link_stats *stats);
-void __connman_ipconfig_newaddr(int index, const char *label,
+void __connman_ipconfig_newaddr(int index, int family, const char *label,
 				unsigned char prefixlen, const char *address);
-void __connman_ipconfig_deladdr(int index, const char *label,
+void __connman_ipconfig_deladdr(int index, int family, const char *label,
 				unsigned char prefixlen, const char *address);
-void __connman_ipconfig_newroute(int index, unsigned char scope,
+void __connman_ipconfig_newroute(int index, int family, unsigned char scope,
 					const char *dst, const char *gateway);
-void __connman_ipconfig_delroute(int index, unsigned char scope,
+void __connman_ipconfig_delroute(int index, int family, unsigned char scope,
 					const char *dst, const char *gateway);
 
 void __connman_ipconfig_foreach(void (*function) (int index, void *user_data),
@@ -236,18 +234,30 @@ void __connman_ipconfig_append_ipv4(struct connman_ipconfig *ipconfig,
 							DBusMessageIter *iter);
 void __connman_ipconfig_append_ipv4config(struct connman_ipconfig *ipconfig,
 							DBusMessageIter *iter);
-int __connman_ipconfig_set_ipv4config(struct connman_ipconfig *ipconfig,
-							DBusMessageIter *value);
-void __connman_ipconfig_append_proxy(struct connman_ipconfig *ipconfig,
+void __connman_ipconfig_append_ipv6(struct connman_ipconfig *ipconfig,
 							DBusMessageIter *iter);
+void __connman_ipconfig_append_ipv6config(struct connman_ipconfig *ipconfig,
+							DBusMessageIter *iter);
+int __connman_ipconfig_set_config(struct connman_ipconfig *ipconfig,
+		enum connman_ipconfig_type type, DBusMessageIter *array);
 void __connman_ipconfig_append_ethernet(struct connman_ipconfig *ipconfig,
 							DBusMessageIter *iter);
 enum connman_ipconfig_method __connman_ipconfig_get_method(
 				struct connman_ipconfig *ipconfig);
+
+void __connman_ipconfig_set_element_ipv6_gateway(
+			struct connman_ipconfig *ipconfig,
+				struct connman_element *element);
+
 int __connman_ipconfig_set_gateway(struct connman_ipconfig *ipconfig,
 					struct connman_element *parent);
 int __connman_ipconfig_set_address(struct connman_ipconfig *ipconfig);
 int __connman_ipconfig_clear_address(struct connman_ipconfig *ipconfig);
+unsigned char __connman_ipconfig_netmask_prefix_len(const char *netmask);
+
+int __connman_ipconfig_set_proxy_autoconfig(struct connman_ipconfig *ipconfig,
+							const char *url);
+const char *__connman_ipconfig_get_proxy_autoconfig(struct connman_ipconfig *ipconfig);
 
 int __connman_ipconfig_load(struct connman_ipconfig *ipconfig,
 		GKeyFile *keyfile, const char *identifier, const char *prefix);
@@ -277,12 +287,13 @@ void __connman_connection_cleanup(void);
 
 gboolean __connman_connection_update_gateway(void);
 
-int __connman_udev_init(void);
-void __connman_udev_start(void);
-void __connman_udev_cleanup(void);
-char *__connman_udev_get_devtype(const char *ifname);
-void __connman_udev_rfkill(const char *sysname, connman_bool_t blocked);
-connman_bool_t __connman_udev_get_blocked(int phyindex);
+int __connman_wpad_init(void);
+void __connman_wpad_cleanup(void);
+void __connman_wpad_start(struct connman_service *service);
+void __connman_wpad_stop(struct connman_service *service);
+
+int __connman_wispr_init(void);
+void __connman_wispr_cleanup(void);
 
 #include <connman/technology.h>
 
@@ -305,8 +316,10 @@ void __connman_technology_add_interface(enum connman_service_type type,
 				int index, const char *name, const char *ident);
 void __connman_technology_remove_interface(enum connman_service_type type,
 				int index, const char *name, const char *ident);
-int __connman_technology_enable_tethering(void);
-int __connman_technology_disable_tethering(void);
+int __connman_technology_enable_tethering(const char *bridge);
+int __connman_technology_disable_tethering(const char *bridge);
+
+connman_bool_t __connman_technology_get_blocked(enum connman_service_type type);
 
 #include <connman/device.h>
 
@@ -322,6 +335,7 @@ void __connman_device_set_phyindex(struct connman_device *device,
 							int phyindex);
 int __connman_device_set_blocked(struct connman_device *device,
 						connman_bool_t blocked);
+connman_bool_t __connman_device_get_blocked(struct connman_device *device);
 
 void __connman_device_increase_connections(struct connman_device *device);
 void __connman_device_decrease_connections(struct connman_device *device);
@@ -344,7 +358,6 @@ void __connman_device_set_reconnect(struct connman_device *device,
 connman_bool_t __connman_device_get_reconnect(struct connman_device *device);
 
 const char *__connman_device_get_type(struct connman_device *device);
-const char *__connman_device_get_ident(struct connman_device *device);
 
 int __connman_device_set_offlinemode(connman_bool_t offlinemode);
 
@@ -382,7 +395,7 @@ int __connman_profile_init();
 void __connman_profile_cleanup(void);
 
 connman_bool_t __connman_profile_get_offlinemode(void);
-int __connman_profile_set_offlinemode(connman_bool_t offlinemode);
+int __connman_profile_set_offlinemode(connman_bool_t offlinemode, connman_bool_t all_devices);
 int __connman_profile_save_default(void);
 
 void __connman_profile_list(DBusMessageIter *iter, void *user_data);
@@ -407,6 +420,24 @@ void __connman_tethering_cleanup(void);
 connman_bool_t __connman_tethering_get_status(void);
 int __connman_tethering_set_status(connman_bool_t status);
 void __connman_tethering_update_interface(const char *interface);
+void __connman_tethering_set_enabled(void);
+void __connman_tethering_set_disabled(void);
+
+#include <connman/provider.h>
+
+void __connman_provider_append_properties(struct connman_provider *provider, DBusMessageIter *iter);
+void __connman_provider_list(DBusMessageIter *iter, void *user_data);
+int __connman_provider_create_and_connect(DBusMessage *msg);
+const char * __connman_provider_get_ident(struct connman_provider *provider);
+int __connman_provider_indicate_state(struct connman_provider *provider,
+					enum connman_provider_state state);
+int __connman_provider_indicate_error(struct connman_provider *provider,
+					enum connman_provider_error error);
+int __connman_provider_connect(struct connman_provider *provider);
+int __connman_provider_disconnect(struct connman_provider *provider);
+int __connman_provider_remove(const char *path);
+void __connman_provider_cleanup(void);
+int __connman_provider_init(void);
 
 #include <connman/service.h>
 
@@ -420,7 +451,9 @@ const char *__connman_service_default(void);
 void __connman_service_put(struct connman_service *service);
 
 struct connman_service *__connman_service_lookup_from_network(struct connman_network *network);
+struct connman_service *__connman_service_lookup_from_index(int index);
 struct connman_service *__connman_service_create_from_network(struct connman_network *network);
+struct connman_service *__connman_service_create_from_provider(struct connman_provider *provider);
 void __connman_service_update_from_network(struct connman_network *network);
 void __connman_service_remove_from_network(struct connman_network *network);
 
@@ -428,9 +461,11 @@ void __connman_service_create_ipconfig(struct connman_service *service,
 								int index);
 struct connman_ipconfig *__connman_service_get_ipconfig(
 				struct connman_service *service);
+const char *__connman_service_get_ident(struct connman_service *service);
 const char *__connman_service_get_path(struct connman_service *service);
 unsigned int __connman_service_get_order(struct connman_service *service);
 struct connman_network *__connman_service_get_network(struct connman_service *service);
+enum connman_service_security __connman_service_get_security(struct connman_service *service);
 int __connman_service_set_favorite(struct connman_service *service,
 						connman_bool_t favorite);
 int __connman_service_set_immutable(struct connman_service *service,
@@ -462,20 +497,25 @@ void __connman_service_nameserver_add_routes(struct connman_service *service,
 						const char *gw);
 void __connman_service_nameserver_del_routes(struct connman_service *service);
 
-unsigned long __connman_service_stats_get_rx_packets(struct connman_service *service);
-unsigned long __connman_service_stats_get_tx_packets(struct connman_service *service);
-unsigned long __connman_service_stats_get_rx_bytes(struct connman_service *service);
-unsigned long __connman_service_stats_get_tx_bytes(struct connman_service *service);
-unsigned long __connman_service_stats_get_rx_errors(struct connman_service *service);
-unsigned long __connman_service_stats_get_tx_errors(struct connman_service *service);
-unsigned long __connman_service_stats_get_rx_dropped(struct connman_service *service);
-unsigned long __connman_service_stats_get_tx_dropped(struct connman_service *service);
-unsigned long __connman_service_stats_get_time(struct connman_service *service);
-void __connman_service_stats_update(struct connman_service *service,
-				unsigned int rx_packets, unsigned int tx_packets,
-				unsigned int rx_bytes, unsigned int tx_bytes,
-				unsigned int rx_error, unsigned int tx_error,
-				unsigned int rx_dropped, unsigned int tx_dropped);
+int __connman_service_get_index(struct connman_service *service);
+void __connman_service_set_domainname(struct connman_service *service,
+						const char *domainname);
+const char *__connman_service_get_domainname(struct connman_service *service);
+const char *__connman_service_get_nameserver(struct connman_service *service);
+void __connman_service_set_proxy_autoconfig(struct connman_service *service,
+							const char *url);
+
+void __connman_service_set_passphrase(struct connman_service *service,
+					const char* passphrase);
+
+void __connman_service_notify(struct connman_ipconfig *ipconfig,
+			unsigned int rx_packets, unsigned int tx_packets,
+			unsigned int rx_bytes, unsigned int tx_bytes,
+			unsigned int rx_error, unsigned int tx_error,
+			unsigned int rx_dropped, unsigned int tx_dropped);
+
+int __connman_service_counter_register(const char *counter);
+void __connman_service_counter_unregister(const char *counter);
 
 #include <connman/location.h>
 
@@ -488,18 +528,6 @@ struct connman_location *__connman_service_get_location(struct connman_service *
 int __connman_location_detect(struct connman_service *service);
 int __connman_location_finish(struct connman_service *service);
 
-#include <connman/provider.h>
-
-void __connman_provider_list(DBusMessageIter *iter, void *user_data);
-int __connman_provider_create_and_connect(DBusMessage *msg);
-int __connman_provider_indicate_state(struct connman_provider *provider,
-				     enum connman_provider_state state);
-int __connman_provider_indicate_error(struct connman_provider *provider,
-				     enum connman_provider_error error);
-int __connman_provider_remove(const char *path);
-void __connman_provider_cleanup(void);
-int __connman_provider_init(void);
-
 #include <connman/notifier.h>
 
 int __connman_technology_init(void);
@@ -532,6 +560,7 @@ int __connman_rtnl_init(void);
 void __connman_rtnl_start(void);
 void __connman_rtnl_cleanup(void);
 
+enum connman_device_type __connman_rtnl_get_device_type(int index);
 unsigned int __connman_rtnl_update_interval_add(unsigned int interval);
 unsigned int __connman_rtnl_update_interval_remove(unsigned int interval);
 int __connman_rtnl_request_update(void);
@@ -541,3 +570,35 @@ int __connman_session_release(const char *owner);
 struct connman_service *__connman_session_request(const char *bearer, const char *owner);
 int __connman_session_init(void);
 void __connman_session_cleanup(void);
+
+int __connman_ondemand_init(void);
+void __connman_ondemand_cleanup(void);
+
+struct connman_stats_data {
+	unsigned int rx_packets;
+	unsigned int tx_packets;
+	unsigned int rx_bytes;
+	unsigned int tx_bytes;
+	unsigned int rx_errors;
+	unsigned int tx_errors;
+	unsigned int rx_dropped;
+	unsigned int tx_dropped;
+	unsigned int time;
+};
+
+int __connman_stats_init(void);
+void __connman_stats_cleanup(void);
+int __connman_stats_service_register(struct connman_service *service);
+void __connman_stats_service_unregister(struct connman_service *service);
+int  __connman_stats_update(struct connman_service *service,
+				connman_bool_t roaming,
+				struct connman_stats_data *data);
+int __connman_stats_get(struct connman_service *service,
+				connman_bool_t roaming,
+				struct connman_stats_data *data);
+
+int __connman_iptables_init(void);
+void __connman_iptables_cleanup(void);
+int __connman_iptables_command(const char *format, ...)
+				__attribute__((format(printf, 1, 2)));
+int __connman_iptables_commit(const char *table_name);
