@@ -26,8 +26,6 @@
 #include <errno.h>
 #include <string.h>
 
-#include <gdbus.h>
-
 #include "connman.h"
 
 static unsigned int hidden_counter = 0;
@@ -35,7 +33,6 @@ static unsigned int hidden_counter = 0;
 struct connman_network {
 	struct connman_element element;
 	enum connman_network_type type;
-	enum connman_network_protocol protocol;
 	connman_bool_t available;
 	connman_bool_t connected;
 	connman_bool_t roaming;
@@ -52,7 +49,6 @@ struct connman_network {
 	struct connman_network_driver *driver;
 	void *driver_data;
 
-	connman_bool_t registered;
 	connman_bool_t connecting;
 	connman_bool_t associating;
 
@@ -97,159 +93,12 @@ static const char *type2string(enum connman_network_type type)
 	return NULL;
 }
 
-static DBusMessage *get_properties(DBusConnection *conn,
-					DBusMessage *msg, void *data)
-{
-	struct connman_network *network = data;
-	DBusMessage *reply;
-	DBusMessageIter array, dict;
-
-	DBG("conn %p", conn);
-
-	if (__connman_security_check_privilege(msg,
-					CONNMAN_SECURITY_PRIVILEGE_PUBLIC) < 0)
-		return __connman_error_permission_denied(msg);
-
-	reply = dbus_message_new_method_return(msg);
-	if (reply == NULL)
-		return NULL;
-
-	dbus_message_iter_init_append(reply, &array);
-
-	connman_dbus_dict_open(&array, &dict);
-
-	if (network->device) {
-		const char *path = connman_device_get_path(network->device);
-		if (path != NULL)
-			connman_dbus_dict_append_basic(&dict, "Device",
-						DBUS_TYPE_OBJECT_PATH, &path);
-	}
-
-	if (network->address != NULL)
-		connman_dbus_dict_append_basic(&dict, "Address",
-					DBUS_TYPE_STRING, &network->address);
-
-	if (network->name != NULL)
-		connman_dbus_dict_append_basic(&dict, "Name",
-					DBUS_TYPE_STRING, &network->name);
-
-	connman_dbus_dict_append_basic(&dict, "Connected",
-				DBUS_TYPE_BOOLEAN, &network->connected);
-
-	if (network->strength > 0)
-		connman_dbus_dict_append_basic(&dict, "Strength",
-					DBUS_TYPE_BYTE, &network->strength);
-
-	if (network->frequency > 0)
-		connman_dbus_dict_append_basic(&dict, "Frequency",
-					DBUS_TYPE_UINT16, &network->frequency);
-
-	if (network->wifi.ssid != NULL && network->wifi.ssid_len > 0)
-		connman_dbus_dict_append_fixed_array(&dict, "WiFi.SSID",
-				DBUS_TYPE_BYTE, &network->wifi.ssid,
-						network->wifi.ssid_len);
-
-	if (network->wifi.mode != NULL)
-		connman_dbus_dict_append_basic(&dict, "WiFi.Mode",
-				DBUS_TYPE_STRING, &network->wifi.mode);
-
-	if (network->wifi.channel > 0)
-		connman_dbus_dict_append_basic(&dict, "WiFi.Channel",
-				DBUS_TYPE_UINT16, &network->wifi.channel);
-
-	if (network->wifi.security != NULL) {
-		connman_dbus_dict_append_basic(&dict, "WiFi.Security",
-				DBUS_TYPE_STRING, &network->wifi.security);
-
-		if (g_strcmp0(network->wifi.security, "ieee8021x") == 0 &&
-						    network->wifi.eap != NULL)
-			connman_dbus_dict_append_basic(&dict, "WiFi.EAP",
-					DBUS_TYPE_STRING, &network->wifi.eap);
-	}
-
-
-	if (network->wifi.passphrase != NULL &&
-			__connman_security_check_privilege(msg,
-				CONNMAN_SECURITY_PRIVILEGE_SECRET) == 0)
-		connman_dbus_dict_append_basic(&dict, "WiFi.Passphrase",
-				DBUS_TYPE_STRING, &network->wifi.passphrase);
-
-	connman_dbus_dict_close(&array, &dict);
-
-	return reply;
-}
-
-static GDBusMethodTable network_methods[] = {
-	{ "GetProperties", "",   "a{sv}", get_properties },
-	{ },
-};
-
-static GDBusSignalTable network_signals[] = {
-	{ "PropertyChanged", "sv" },
-	{ },
-};
-
-static DBusConnection *connection;
-
-static void append_networks(DBusMessageIter *iter, void *user_data)
-{
-	struct connman_device *device = user_data;
-
-	__connman_element_list((struct connman_element *) device,
-					CONNMAN_ELEMENT_TYPE_NETWORK, iter);
-}
-
-static void emit_networks_signal(struct connman_device *device)
-{
-	const char *path = connman_device_get_path(device);
-
-	connman_dbus_property_changed_array(path,
-			CONNMAN_DEVICE_INTERFACE, "Networks",
-			DBUS_TYPE_OBJECT_PATH, append_networks, device);
-}
-
-static int register_interface(struct connman_element *element)
-{
-	struct connman_network *network = element->network;
-
-	DBG("element %p name %s", element, element->name);
-
-	if (g_dbus_register_interface(connection, element->path,
-					CONNMAN_NETWORK_INTERFACE,
-					network_methods, network_signals,
-					NULL, network, NULL) == FALSE) {
-		connman_error("Failed to register %s network", element->path);
-		return -EIO;
-	}
-
-	network->registered = TRUE;
-
-	emit_networks_signal(network->device);
-
-	return 0;
-}
-
-static void unregister_interface(struct connman_element *element)
-{
-	struct connman_network * network = element->network;
-
-	DBG("element %p name %s", element, element->name);
-
-	network->registered = FALSE;
-
-	if (network->device != NULL)
-		emit_networks_signal(network->device);
-
-	g_dbus_unregister_interface(connection, element->path,
-						CONNMAN_NETWORK_INTERFACE);
-}
-
 connman_bool_t __connman_network_has_driver(struct connman_network *network)
 {
 	if (network == NULL || network->driver == NULL)
 		return FALSE;
 
-	return network->registered;
+	return TRUE;
 }
 
 static GSList *driver_list = NULL;
@@ -272,8 +121,18 @@ static gint compare_priority(gconstpointer a, gconstpointer b)
  */
 int connman_network_driver_register(struct connman_network_driver *driver)
 {
+	GSList *list;
+
 	DBG("driver %p name %s", driver, driver->name);
 
+	for (list = driver_list; list; list = list->next) {
+		struct connman_network_driver *tmp = list->data;
+
+		if (tmp->type == driver->type)
+			return -EALREADY;
+
+	}
+
 	driver_list = g_slist_insert_sorted(driver_list, driver,
 							compare_priority);
 
@@ -344,7 +203,6 @@ struct connman_network *connman_network_create(const char *identifier,
 
 	__connman_element_initialize(&network->element);
 
-	//temp = connman_dbus_encode_string(identifier);
 	if (identifier == NULL) {
 		temp = g_strdup_printf("hidden_%d", hidden_counter++);
 		network->hidden = TRUE;
@@ -426,17 +284,6 @@ const char *connman_network_get_identifier(struct connman_network *network)
 	return network->identifier;
 }
 
-/**
- * connman_network_get_path:
- * @network: network structure
- *
- * Get path name of network
- */
-const char *connman_network_get_path(struct connman_network *network)
-{
-	return network->element.path;
-}
-
 /**
  * connman_network_set_index:
  * @network: network structure
@@ -497,19 +344,6 @@ struct connman_element *connman_network_get_element(
 	return &network->element;
 }
 
-/**
- * connman_network_set_protocol:
- * @network: network structure
- * @protocol: network protocol
- *
- * Change protocol of network
- */
-void connman_network_set_protocol(struct connman_network *network,
-					enum connman_network_protocol protocol)
-{
-	network->protocol = protocol;
-}
-
 /**
  * connman_network_set_group:
  * @network: network structure
@@ -548,7 +382,7 @@ void connman_network_set_group(struct connman_network *network,
 	network->group = g_strdup(group);
 
 	if (network->group != NULL)
-		__connman_profile_add_network(network);
+			__connman_profile_add_network(network);
 }
 
 /**
@@ -567,7 +401,7 @@ const char *__connman_network_get_ident(struct connman_network *network)
 	if (network->device == NULL)
 		return NULL;
 
-	return __connman_device_get_ident(network->device);
+	return connman_device_get_ident(network->device);
 }
 
 connman_bool_t __connman_network_get_weakness(struct connman_network *network)
@@ -824,9 +658,6 @@ static int set_connected_dhcp(struct connman_network *network)
 
 	DBG("network %p", network);
 
-	if (network->protocol != CONNMAN_NETWORK_PROTOCOL_IP)
-		return -EINVAL;
-
 	element = connman_element_create(NULL);
 	if (element == NULL)
 		return -ENOMEM;
@@ -978,15 +809,6 @@ int connman_network_set_connected(struct connman_network *network,
 
 	network->connected = connected;
 
-	if (network->registered == FALSE) {
-		g_idle_add(set_connected, network);
-		return 0;
-	}
-
-	connman_dbus_property_changed_basic(network->element.path,
-				CONNMAN_NETWORK_INTERFACE, "Connected",
-						DBUS_TYPE_BOOLEAN, &connected);
-
 	set_connected(network);
 
 	return 0;
@@ -1039,6 +861,9 @@ int __connman_network_connect(struct connman_network *network)
 	if (network->driver->connect == NULL)
 		return -ENOSYS;
 
+	if (network->device == NULL)
+		return -ENODEV;
+
 	__connman_device_disconnect(network->device);
 
 	network->connecting = TRUE;
@@ -1101,9 +926,6 @@ static int dhcp_start(struct connman_network *network)
 	struct connman_element *element;
 	int error;
 
-	if (network->protocol != CONNMAN_NETWORK_PROTOCOL_IP)
-		return -EINVAL;
-
 	element = connman_element_create(NULL);
 	if (element == NULL)
 		return -ENOMEM;
@@ -1122,9 +944,6 @@ static int dhcp_start(struct connman_network *network)
 
 static int dhcp_stop(struct connman_network *network)
 {
-	if (network->protocol != CONNMAN_NETWORK_PROTOCOL_IP)
-		return -EINVAL;
-
 	connman_element_unregister_children_type(&network->element,
 					CONNMAN_ELEMENT_TYPE_CONNECTION);
 	connman_element_unregister_children_type(&network->element,
@@ -1431,6 +1250,34 @@ const char *connman_network_get_string(struct connman_network *network,
 	return connman_element_get_string(&network->element, key);
 }
 
+/**
+ * connman_network_set_passphrase:
+ * @network: network structure
+ * @passphrase: network passphrase
+ *
+ * Set network passphrase.
+ * If the network is linked to a service, the latter gets his passphrase
+ * set as well.
+ */
+int connman_network_set_passphrase(struct connman_network *network,
+						const char* passphrase)
+{
+	struct connman_service *service;
+
+	service = __connman_service_lookup_from_network(network);
+	if (service == NULL) {
+		connman_network_set_string(network, "WiFi.Passphrase",
+						passphrase);
+
+		return 0;
+	}
+
+	__connman_service_set_passphrase(service, passphrase);
+
+	return 0;
+}
+
+
 /**
  * connman_network_set_bool:
  * @network: network structure
@@ -1673,7 +1520,6 @@ static int network_probe(struct connman_element *element)
 {
 	struct connman_network *network = element->network;
 	GSList *list;
-	int err;
 
 	DBG("element %p name %s", element, element->name);
 
@@ -1697,13 +1543,6 @@ static int network_probe(struct connman_element *element)
 	if (network->driver == NULL)
 		return -ENODEV;
 
-	err = register_interface(element);
-	if (err < 0) {
-		if (network->driver->remove)
-			network->driver->remove(network);
-		return err;
-	}
-
 	switch (network->type) {
 	case CONNMAN_NETWORK_TYPE_UNKNOWN:
 	case CONNMAN_NETWORK_TYPE_VENDOR:
@@ -1753,8 +1592,6 @@ static void network_remove(struct connman_element *element)
 		break;
 	}
 
-	unregister_interface(element);
-
 	if (network->driver->remove)
 		network->driver->remove(network);
 }
@@ -1799,8 +1636,6 @@ int __connman_network_init(void)
 {
 	DBG("");
 
-	connection = connman_dbus_get_connection();
-
 	return connman_driver_register(&network_driver);
 }
 
@@ -1809,6 +1644,4 @@ void __connman_network_cleanup(void)
 	DBG("");
 
 	connman_driver_unregister(&network_driver);
-
-	dbus_connection_unref(connection);
 }
